animal.points: Example animal location data

animal.pointsR Documentation

Example animal location data

Description

Hypothetical data set with the GPS coordinates for two turtles

Usage

animal.points

Format

A data frame with 11 rows and 5 columns:

lon.raw

Longitude in decimal degrees

lat.raw

Latitude in decimal degrees

lon.shifted

Longitude shifted to line up with stream points to illustrate how the functions work

lat.shifted

Latitude shifted to line up with stream points to illustrate how the functions work

id

Turtle IDs

date.time

Dates and times of points in POSIX format

point

Names of each coordinate (optional)

Fictional example generated to demonstrate this package


SNMA documentation built on Aug. 27, 2026, 1:08 a.m.