node.dist: Calculate minimum distance between all pairs of nodes

View source: R/node.dist.R

node.distR Documentation

Calculate minimum distance between all pairs of nodes

Description

For a given network of nodes and distances, it will use Dijkstra’s algorithm via igraph to calculate the minimum distance between each pair of nodes following the river network.

Usage

node.dist(x)

Arguments

x

(data.frame) The segement object created using dist.per.segment

Value

A data frame containing the name of the first node, name of the second node, and distance between them (in meters). The diagonal of the distance matrix is not returned, and there are no duplicate pairs.


SNMA documentation built on Aug. 27, 2026, 1:08 a.m.