| animal.points | R Documentation |
Hypothetical data set with the GPS coordinates for two turtles
animal.points
A data frame with 11 rows and 5 columns:
Longitude in decimal degrees
Latitude in decimal degrees
Longitude shifted to line up with stream points to illustrate how the functions work
Latitude shifted to line up with stream points to illustrate how the functions work
Turtle IDs
Dates and times of points in POSIX format
Names of each coordinate (optional)
Fictional example generated to demonstrate this package
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.