| node.dist | R Documentation |
For a given network of nodes and distances, it will use Dijkstra’s algorithm via igraph to calculate the minimum distance between each pair of nodes following the river network.
node.dist(x)
x |
(data.frame) The |
A data frame containing the name of the first node, name of the second node, and distance between them (in meters). The diagonal of the distance matrix is not returned, and there are no duplicate pairs.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.